componenttools.partition_components_cyclically_by_prolated_durations_exactly_without_overhang
=============================================================================================

.. autofunction:: abjad.tools.componenttools.partition_components_cyclically_by_prolated_durations_exactly_without_overhang
